/*
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 *
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-2001 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Contributor(s):
 *   Don Bragg (dbragg@netscape.com) 12/08/1999
 *   Blake Ross (BlakeR1234@aol.com)  6/12/2000
 *
 */

/* ===== xpinstall.css ==================================================
  == Styles used by the XPInstall dialogs.
  ======================================================================= */

@import url("chrome://global/skin");

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

/* ::::: Install Confirm and Progress dialogs ::::: */

#mainBox {
  margin: 5px;
  width: 40em;
}

.headline {
  margin: 4px;
  font-size: x-large;
  font-weight: bold;
}

#modulesTree {
  height: 16ex;
}

[id="dialog.progress"] {
  width: 200px;
}

.vertical-small-spacer {
  height: 1ex;
}

